@@ -10,11 +10,15 @@ _LOGGER = logging.getLogger(__name__)
 class RoborockEnum(IntEnum):
     """Roborock Enum for codes with int values"""
 
+    @property
+    def name(self) -> str:
+        return super().name.lower()
+
     @classmethod
     def _missing_(cls: Type[RoborockEnum], key) -> RoborockEnum:
-        if hasattr(cls, "missing"):
-            _LOGGER.warning(f"Missing {cls.__name__} code: {key} - defaulting to 'missing'")
-            return cls.missing  # type: ignore
+        if hasattr(cls, "unknown"):
+            _LOGGER.warning(f"Missing {cls.__name__} code: {key} - defaulting to 'unknown'")
+            return cls.unknown  # type: ignore
         default_value = next(item for item in cls)
         _LOGGER.warning(f"Missing {cls.__name__} code: {key} - defaulting to {default_value}")
         return default_value
@@ -127,11 +131,11 @@ class RoborockFanSpeedV3(RoborockFanPowerCode):
 
 
 class RoborockFanSpeedE2(RoborockFanPowerCode):
-    gentle = 41
-    silent = 50
-    standard = 68
-    medium = 79
-    turbo = 100
+    quiet = 101
+    balanced = 102
+    turbo = 103
+    max = 104
+    gentle = 105
 
 
 class RoborockFanSpeedS7(RoborockFanPowerCode):
@@ -216,13 +220,15 @@ class RoborockDockErrorCode(RoborockEnum):
     """Describes the error code of the dock."""
 
     ok = 0
+    duct_blockage = 34
     water_empty = 38
     waste_water_tank_full = 39
 
 
 class RoborockDockTypeCode(RoborockEnum):
-    missing = -9999
+    unknown = -9999
     no_dock = 0
+    auto_empty_dock = 1
     empty_wash_fill_dock = 3
     auto_empty_dock_pure = 5
     s8_dock = 7
@@ -232,7 +238,7 @@ class RoborockDockDustCollectionModeCode(RoborockEnum):
     """Describes the dust collection mode of the vacuum cleaner."""
 
     # TODO: Get the correct values for various different docks
-    missing = -9999
+    unknown = -9999
     smart = 0
     light = 1
     balanced = 2
@@ -243,7 +249,7 @@ class RoborockDockWashTowelModeCode(RoborockEnum):
     """Describes the wash towel mode of the vacuum cleaner."""
 
     # TODO: Get the correct values for various different docks
-    missing = -9999
+    unknown = -9999
     light = 0
     balanced = 1
     deep = 2
