@@ -221,6 +221,7 @@ class Status(RoborockBase):
     battery: Optional[int] = None
     clean_time: Optional[int] = None
     clean_area: Optional[int] = None
+    square_meter_clean_area: Optional[float] = None
     error_code: Optional[RoborockErrorCode] = None
     map_present: Optional[int] = None
     in_cleaning: Optional[int] = None
@@ -258,6 +259,9 @@ class Status(RoborockBase):
     unsave_map_reason: Optional[int] = None
     unsave_map_flag: Optional[int] = None
 
+    def __post_init__(self) -> None:
+        self.square_meter_clean_area = round(self.clean_area / 1000000, 1) if self.clean_area is not None else None
+
 
 @dataclass
 class S4MaxStatus(Status):
@@ -345,10 +349,14 @@ class DnDTimer(RoborockBase):
 class CleanSummary(RoborockBase):
     clean_time: Optional[int] = None
     clean_area: Optional[int] = None
+    square_meter_clean_area: Optional[float] = None
     clean_count: Optional[int] = None
     dust_collection_count: Optional[int] = None
     records: Optional[list[int]] = None
 
+    def __post_init__(self) -> None:
+        self.square_meter_clean_area = round(self.clean_area / 1000000, 1) if self.clean_area is not None else None
+
 
 @dataclass
 class CleanRecord(RoborockBase):
@@ -356,6 +364,7 @@ class CleanRecord(RoborockBase):
     end: Optional[int] = None
     duration: Optional[int] = None
     area: Optional[int] = None
+    square_meter_area: Optional[float] = None
     error: Optional[int] = None
     complete: Optional[int] = None
     start_type: Optional[int] = None
@@ -366,6 +375,9 @@ class CleanRecord(RoborockBase):
     wash_count: Optional[int] = None
     map_flag: Optional[int] = None
 
+    def __post_init__(self) -> None:
+        self.square_meter_area = round(self.area / 1000000, 1) if self.area is not None else None
+
 
 @dataclass
 class Consumable(RoborockBase):
@@ -382,7 +394,7 @@ class Consumable(RoborockBase):
     filter_time_left: Optional[int] = None
     sensor_time_left: Optional[int] = None
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         self.main_brush_time_left = (
             MAIN_BRUSH_REPLACE_TIME - self.main_brush_work_time if self.main_brush_work_time is not None else None
         )
